@@ -1,3 +1,3 @@
 def Manfred():
     import PLManfred.skript as s
-    setup()
+    s.setup()
